@@ -3,7 +3,7 @@
 
 LCS <- function(a, b){
     stopifnot(is.character(a), is.character(b))
-    if(any(is.na(c(a, b)))){
+    if(any(is.na(c(a, b))) | any(list(a, b) == "")){
        out <- list(a = a, b = b, LLCS = NA, LCS = NA, QSI = NA, va = NA, vb = NA)
     } else {
        out <- .Call("lcs", as.character(a), as.character(b), max(nchar(c(a, b))), PACKAGE="qualV")
@@ -11,7 +11,7 @@ LCS <- function(a, b){
     invisible(out)
 }
 
-
+## original, pure R version of LCS
 #LCS <- function (a, b) {
 #  m <- length(a)
 #  n <- length(b)
